diff --git a/.github/workflows/issue_bot.yml b/.github/workflows/issue_bot.yml
index 21ab4119f..88d36d264 100644
--- a/.github/workflows/issue_bot.yml
+++ b/.github/workflows/issue_bot.yml
@@ -19,6 +19,7 @@ jobs:
stale-issue-label: 'stale'
stale-issue-message: 'As this issue is marked as “wait 4 close” and there was no activity for 5 days, it is now marked as “stale.” It will be automatically closed in 3 more days.'
close-issue-message: 'This issue was closed because it had been inactive for 3 days since being marked as "stale".'
+ close-issue-reason: 'completed'
days-before-pr-stale: -1
days-before-pr-close: -1
repo-token: ${{ secrets.GITHUB_TOKEN }}
diff --git a/README.md b/README.md
index 04c040620..ae073f115 100644
--- a/README.md
+++ b/README.md
@@ -38,7 +38,6 @@ https://demo.wavelog.org
Notes
* If you want to log microwave QSOs you will need to use a 64bit operating system.
-* We do not provide Docker support, however you are free to use it if you wish but we will not handle support.
## Setup
@@ -53,11 +52,11 @@ Wavelog-support can be reached by creating an issue here at github. If you've an
Special thanks to our contributors, who are part of Wavelog by improving code!
-[F4ANS](https://github.com/abarrau), [DG0TM](https://github.com/dg0tm), [DG9VH](https://github.com/dg9vh), [DJ3CE](https://github.com/dj3ce), [R1BLH](https://github.com/r1blh), [BG2ELG](https://github.com/violarulan), [DF1ASH](https://github.com/derFogel), [DB4SCW](https://github.com/DB4SCW), [VE2HEW](https://github.com/anthonydiiorio)
+[F4ANS](https://github.com/abarrau), [DG0TM](https://github.com/dg0tm), [DG9VH](https://github.com/dg9vh), [DJ3CE](https://github.com/dj3ce), [R1BLH](https://github.com/r1blh), [BG2ELG](https://github.com/violarulan), [DF1ASH](https://github.com/derFogel), [DB4SCW](https://github.com/DB4SCW), [VE2HEW](https://github.com/anthonydiiorio), [OK1GOD](https://github.com/filipmelik), [DJ1PW](https://github.com/winnieXY), [toseppo](https://github.com/toseppo), [N7DSB](https://github.com/desertblade), [BA7LAC](https://github.com/imlonghao)
Translators:
-[Ondřej Koloničný (OK1CDJ)](https://translate.wavelog.org/user/ok1cdj/), [Michael Skolsky (R1BLH)](https://translate.wavelog.org/user/R1BLH/), [Karuru (BG2ELG)](https://translate.wavelog.org/user/viola/), [Byt3](https://translate.wavelog.org/user/205er/), [BG6HJE](https://translate.wavelog.org/user/BG6HJE/), [Francisco (F4VSE)](https://translate.wavelog.org/user/kikosgc/), [Kim (DG9VH)](https://translate.wavelog.org/user/dg9vh/), [Casper van Lieburg (PA7DX)](https://translate.wavelog.org/user/pa7dx/), [Halil AYYILDIZ (TA2LG)](https://translate.wavelog.org/user/TA2LG/), [Michal Šiman](https://translate.wavelog.org/user/michalsiman/), [DN4BS](https://github.com/dn4bs)
+[Ondřej Koloničný (OK1CDJ)](https://translate.wavelog.org/user/ok1cdj/), [Michael Skolsky (R1BLH)](https://translate.wavelog.org/user/R1BLH/), [Karuru (BG2ELG)](https://translate.wavelog.org/user/viola/), [Byt3](https://translate.wavelog.org/user/205er/), [BG6HJE](https://translate.wavelog.org/user/BG6HJE/), [Francisco (F4VSE)](https://translate.wavelog.org/user/kikosgc/), [Kim (DG9VH)](https://translate.wavelog.org/user/dg9vh/), [Casper van Lieburg (PA7DX)](https://translate.wavelog.org/user/pa7dx/), [Halil AYYILDIZ (TA2LG)](https://translate.wavelog.org/user/TA2LG/), [Michal Šiman](https://translate.wavelog.org/user/michalsiman/), [DN4BS](https://github.com/dn4bs), [Luca (IU2FRL)](https://translate.wavelog.org/user/iu2frl/), [Dragan Đorđević (4O4A)](https://translate.wavelog.org/user/4o4a/), [Dren Imeraj (Z63DRI)](https://translate.wavelog.org/user/Dren/), [Filip Melik (OK1GOD)](https://translate.wavelog.org/user/filipmelik/), [Petr (OK1PTR)](https://translate.wavelog.org/user/OK1PTR/), [Stefan (DB4SCW)](https://translate.wavelog.org/user/DB4SCW/), [F4JSU](https://translate.wavelog.org/user/F4JSU/), [Maciej](https://translate.wavelog.org/user/maciejla/)
If you would like to contribute in any way to Wavelog, it is most appreciated. This has been developed in free time, help coding new features or writing documentation is always useful.
diff --git a/application/config/config.sample.php b/application/config/config.sample.php
index bc1827e54..335522087 100644
--- a/application/config/config.sample.php
+++ b/application/config/config.sample.php
@@ -669,4 +669,30 @@ $config['disable_oqrs'] = false;
$config['special_callsign'] = false;
// hides the usermenu; takes action only if "special_callsign" is true
-$config['sc_hide_usermenu'] = true;
\ No newline at end of file
+$config['sc_hide_usermenu'] = true;
+
+
+/*
+|--------------------------------------------------------------------------
+| Impersonate
+|--------------------------------------------------------------------------
+|
+| This config switch disables the impersonate feature. This feauture is used to impersonate another user.
+| Impersonate is enabled by default. To disable it, set the value to false.
+|
+*/
+
+$config['disable_impersonate'] = false;
+
+
+/*
+|--------------------------------------------------------------------------
+| Cronmanager Allow Insecure
+|--------------------------------------------------------------------------
+|
+| The cronmanager needs http or https with a valid certificate to work.
+| If you want to use it with https and a self-signed certificate, you need to set this to true.
+|
+*/
+
+$config['cron_allow_insecure'] = false;
\ No newline at end of file
diff --git a/application/config/gettext.php b/application/config/gettext.php
index 120742dec..43d0bfcea 100644
--- a/application/config/gettext.php
+++ b/application/config/gettext.php
@@ -61,6 +61,26 @@ $config['gettext_domain'] = NULL;
*/
$config['languages'] = array(
+ 'albanian' => array(
+ 'name' => 'Shqip',
+ 'name_en' => 'Albanian',
+ 'folder' => 'albanian',
+ 'locale' => 'sq',
+ 'gettext' => 'sq',
+ 'direction' => 'ltr',
+ 'code' => 'sq',
+ 'flag' => 'al',
+ ),
+ 'bosnian' => array(
+ 'name' => 'Bosanski',
+ 'name_en' => 'Bosnian',
+ 'folder' => 'bosnian',
+ 'locale' => 'bs',
+ 'gettext' => 'bs',
+ 'direction' => 'ltr',
+ 'code' => 'bs',
+ 'flag' => 'ba',
+ ),
'bulgarian' => array(
'name' => 'Български',
'name_en' => 'Bulgarian',
@@ -81,6 +101,16 @@ $config['languages'] = array(
'code' => 'zh-Hans',
'flag' => 'cn',
),
+ 'croatian' => array(
+ 'name' => 'Hrvatski',
+ 'name_en' => 'Croatian',
+ 'folder' => 'croatian',
+ 'locale' => 'hr',
+ 'gettext' => 'hr',
+ 'direction' => 'ltr',
+ 'code' => 'hr',
+ 'flag' => 'hr',
+ ),
'czech' => array(
'name' => 'Čeština',
'name_en' => 'Czech',
@@ -161,6 +191,16 @@ $config['languages'] = array(
'code' => 'it',
'flag' => 'it',
),
+ 'montenegrin' => array(
+ 'name' => 'Crnogorski',
+ 'name_en' => 'Montenegrin',
+ 'folder' => 'montenegrin',
+ 'locale' => 'cnr',
+ 'gettext' => 'cnr',
+ 'direction' => 'ltr',
+ 'code' => 'cnr',
+ 'flag' => 'me',
+ ),
'polish' => array(
'name' => 'Polski',
'name_en' => 'Polish',
@@ -191,6 +231,16 @@ $config['languages'] = array(
'code' => 'ru',
'flag' => 'ru',
),
+ 'serbian' => array(
+ 'name' => 'Srpski',
+ 'name_en' => 'Serbian',
+ 'folder' => 'serbian',
+ 'locale' => 'sr',
+ 'gettext' => 'sr',
+ 'direction' => 'ltr',
+ 'code' => 'sr',
+ 'flag' => 'rs',
+ ),
'spanish' => array(
'name' => 'Español',
'name_en' => 'Spanish',
diff --git a/application/config/migration.php b/application/config/migration.php
index 4b866b010..d15efc4d6 100644
--- a/application/config/migration.php
+++ b/application/config/migration.php
@@ -22,7 +22,7 @@ $config['migration_enabled'] = TRUE;
|
*/
-$config['migration_version'] = 214;
+$config['migration_version'] = 218;
/*
|--------------------------------------------------------------------------
diff --git a/application/controllers/Activators.php b/application/controllers/Activators.php
index f50ce1c21..652833dc6 100644
--- a/application/controllers/Activators.php
+++ b/application/controllers/Activators.php
@@ -10,7 +10,7 @@ class Activators extends CI_Controller
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
}
@@ -30,7 +30,7 @@ class Activators extends CI_Controller
if ($this->input->post('mincount') != NULL) { // mincount is not set when page first loads.
$mincount = $this->input->post('mincount');
} else {
- $mincount = 2;
+ $mincount = 2;
}
if ($this->input->post('leogeo') != NULL) { // orbit is not set when page first loads.
@@ -46,7 +46,6 @@ class Activators extends CI_Controller
$data['maxactivatedgrids'] = $this->Activators_model->get_max_activated_grids();
$data['orbit'] = $orbit;
$data['activators_array'] = $this->Activators_model->get_activators($band, $mincount, $orbit);
- $data['activators_vucc_array'] = $this->Activators_model->get_activators_vucc($band, $orbit);
$data['bandselect'] = $band;
$footerData = [];
diff --git a/application/controllers/Activatorsmap.php b/application/controllers/Activatorsmap.php
index 1399f4d0f..288527c7c 100644
--- a/application/controllers/Activatorsmap.php
+++ b/application/controllers/Activatorsmap.php
@@ -10,7 +10,7 @@ class Activatorsmap extends CI_Controller {
parent::__construct();
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
}
public function index() {
diff --git a/application/controllers/Adif.php b/application/controllers/Adif.php
index 4b83bc15e..d23170830 100644
--- a/application/controllers/Adif.php
+++ b/application/controllers/Adif.php
@@ -10,7 +10,7 @@ class adif extends CI_Controller {
$this->load->helper(array('form', 'url'));
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
}
public function test() {
@@ -233,7 +233,16 @@ class adif extends CI_Controller {
array_push($alladif,$record);
};
$record=''; // free memory
- $custom_errors = $this->logbook_model->import_bulk($alladif, $this->input->post('station_profile'), $this->input->post('skipDuplicate'), $this->input->post('markClublog'),$this->input->post('markLotw'), $this->input->post('dxccAdif'), $this->input->post('markQrz'), $this->input->post('markHrd'), true, $this->input->post('operatorName'), false, $this->input->post('skipStationCheck'));
+ try {
+ $custom_errors = $this->logbook_model->import_bulk($alladif, $this->input->post('station_profile'), $this->input->post('skipDuplicate'), $this->input->post('markClublog'),$this->input->post('markLotw'), $this->input->post('dxccAdif'), $this->input->post('markQrz'), $this->input->post('markEqsl'), $this->input->post('markHrd'), true, $this->input->post('operatorName'), false, $this->input->post('skipStationCheck'));
+ } catch (Exception $e) {
+ log_message('error', 'Import error: '.$e->getMessage());
+ $data['page_title'] = __("ADIF Import failed!");
+ $this->load->view('interface_assets/header', $data);
+ $this->load->view('adif/import_failed');
+ $this->load->view('interface_assets/footer');
+ return;
+ }
} else { // Failure, if no ADIF inside ZIP
$data['max_upload'] = ini_get('upload_max_filesize');
$this->load->view('interface_assets/header', $data);
diff --git a/application/controllers/Api.php b/application/controllers/Api.php
index a2bdd5a83..3112c808e 100644
--- a/application/controllers/Api.php
+++ b/application/controllers/Api.php
@@ -115,13 +115,13 @@ class API extends CI_Controller {
function auth($key) {
$this->load->model('api_model');
header("Content-type: text/xml");
- if($this->api_model->access($key) == __("No Key Found") || $this->api_model->access($key) == __("Key Disabled")) {
+ if($this->api_model->access($key) == "No Key Found" || $this->api_model->access($key) == "Key Disabled") {
echo "
Please check your master cron! It should run every minute (* * * * *).';
+ $result['status'] = sprintf(__("Last run occurred more than %s seconds ago.%sPlease check your master cron! It should run every minute (* * * * *)."), $warning_timelimit_seconds, '
');
$result['status_class'] = 'warning';
} else {
- $result['status'] = 'Last run occurred more than ' . ($error_timelimit_seconds / 60) . ' minutes ago.
Seems like your Mastercron isn\'t running!
It should run every minute (* * * * *).';
+ $result['status'] = sprintf(__("Last run occurred more than %s minutes ago.%sSeems like your Mastercron isn't running!%sIt should run every minute (* * * * *)."), ($error_timelimit_seconds / 60), '
', '
');
$result['status_class'] = 'danger';
}
}
} else {
- $result['status'] = 'Not running';
+ $result['status'] = _pgettext("Master Cron", "Not running");
$result['status_class'] = 'danger';
}
diff --git a/application/controllers/Csv.php b/application/controllers/Csv.php
index 9b7c4b7dd..037de83cb 100644
--- a/application/controllers/Csv.php
+++ b/application/controllers/Csv.php
@@ -5,7 +5,7 @@ class Csv extends CI_Controller {
public function index() {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$this->load->model('modes');
$this->load->model('logbook_model');
@@ -28,7 +28,7 @@ class Csv extends CI_Controller {
public function export() {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$this->load->model('csv_model');
// Parameters
diff --git a/application/controllers/Dashboard.php b/application/controllers/Dashboard.php
index a7231554d..180182729 100644
--- a/application/controllers/Dashboard.php
+++ b/application/controllers/Dashboard.php
@@ -25,6 +25,18 @@ class Dashboard extends CI_Controller
$this->load->model('logbooks_model');
$logbooks_locations_array = $this->logbooks_model->list_logbook_relationships($this->session->userdata('active_station_logbook'));
+
+ if (($logbooks_locations_array[0]>-1) && (!(in_array($this->stations->find_active(),$logbooks_locations_array)))) {
+ $data['active_not_linked']=true;
+ } else {
+ $data['active_not_linked']=false;
+ }
+
+ if ($logbooks_locations_array[0] == -1) {
+ $data['linkedCount']=0;
+ } else {
+ $data['linkedCount']=sizeof($logbooks_locations_array);
+ }
// Calculate Lat/Lng from Locator to use on Maps
if ($this->session->userdata('user_locator')) {
if(!$this->load->is_loaded('Qra')) {
@@ -43,6 +55,9 @@ class Dashboard extends CI_Controller
$data['qra'] = "none";
}
+ // We need the form_helper for the layout/messages
+ $this->load->helper('form');
+
$this->load->model('stations');
$this->load->model('setup_model');
diff --git a/application/controllers/Dayswithqso.php b/application/controllers/Dayswithqso.php
index 9e1bb0862..c82567b55 100644
--- a/application/controllers/Dayswithqso.php
+++ b/application/controllers/Dayswithqso.php
@@ -8,7 +8,7 @@ class Dayswithqso extends CI_Controller {
parent::__construct();
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
}
public function index()
diff --git a/application/controllers/Debug.php b/application/controllers/Debug.php
index e9af0827a..c2c377e41 100644
--- a/application/controllers/Debug.php
+++ b/application/controllers/Debug.php
@@ -7,7 +7,7 @@ class Debug extends CI_Controller
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
diff --git a/application/controllers/Distancerecords.php b/application/controllers/Distancerecords.php
new file mode 100644
index 000000000..54711d2dc
--- /dev/null
+++ b/application/controllers/Distancerecords.php
@@ -0,0 +1,65 @@
+load->model('user_model');
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
+ }
+
+ public function index() {
+
+ $this->load->model('distancerecords_model');
+
+ if($this->session->userdata('user_date_format')) {
+ $custom_date_format = $this->session->userdata('user_date_format');
+ } else {
+ $custom_date_format = $this->config->item('qso_date_format');
+ }
+
+ switch ($custom_date_format) {
+ case 'd/m/y': $usethisformat = 'D/MM/YY';break;
+ case 'd/m/Y': $usethisformat = 'D/MM/YYYY';break;
+ case 'm/d/y': $usethisformat = 'MM/D/YY';break;
+ case 'm/d/Y': $usethisformat = 'MM/D/YYYY';break;
+ case 'd.m.Y': $usethisformat = 'D.MM.YYYY';break;
+ case 'y/m/d': $usethisformat = 'YY/MM/D';break;
+ case 'Y-m-d': $usethisformat = 'YYYY-MM-D';break;
+ case 'M d, Y': $usethisformat = 'MMM D, YYYY';break;
+ case 'M d, y': $usethisformat = 'MMM D, YY';break;
+ }
+
+ $data['scripts'] = [
+ 'assets/js/sections/distancerecords.js',
+ ];
+
+ // Render Page
+ $data['custom_date_format'] = $custom_date_format;
+ $data['page_title'] = __("Satellite Distance Records");
+ $data['distances'] = $this->distancerecords_model->get_records();
+
+ $footerData['usethisformat'] = $usethisformat;
+
+ $this->load->view('interface_assets/header', $data);
+ $this->load->view('distancerecords/index');
+ $this->load->view('interface_assets/footer', $footerData);
+ }
+
+ public function sat_records_ajax() {
+ $this->load->model('distancerecords_model');
+
+ $sat = str_replace('"', "", $this->security->xss_clean($this->input->post("Sat")));
+ $searchmode = $this->input->post('searchmode') == null ? '' : $this->security->xss_clean($this->input->post('searchmode'));
+ $data['results'] = $this->distancerecords_model->sat_distances($sat);
+
+ $data['page_title'] = __("Log View")." - " . __("Satellite Distance Records");
+ $data['filter'] = $sat;
+
+ $this->load->view('distancerecords/details', $data);
+ }
+
+}
diff --git a/application/controllers/Distances.php b/application/controllers/Distances.php
index f68287ca1..af4957501 100644
--- a/application/controllers/Distances.php
+++ b/application/controllers/Distances.php
@@ -8,7 +8,7 @@ class Distances extends CI_Controller {
parent::__construct();
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
}
public function index()
@@ -74,12 +74,13 @@ class Distances extends CI_Controller {
$distance = $this->security->xss_clean($this->input->post('distance'));
$band = $this->security->xss_clean($this->input->post('band'));
$sat = $this->security->xss_clean($this->input->post('sat'));
+ $propagation = $this->security->xss_clean($this->input->post('propagation'));
- $data['results'] = $this->distances_model->qso_details($distance, $band, $sat);
+ $data['results'] = $this->distances_model->qso_details($distance, $band, $sat, $propagation);
// Render Page
$data['page_title'] = "Log View - " . $distance;
- $data['filter'] = __("QSOs with") . " " . $distance . " " . __("and band"). " " . $band;
+ $data['filter'] = __("QSOs with") . " " . $distance . " " . __("and band"). " " . $band. __("and propagation"). " " . $propagation;
$this->load->view('awards/details', $data);
}
}
diff --git a/application/controllers/Dxatlas.php b/application/controllers/Dxatlas.php
index 48cbf81bf..dc10fa4f9 100644
--- a/application/controllers/Dxatlas.php
+++ b/application/controllers/Dxatlas.php
@@ -4,7 +4,7 @@ class Dxatlas extends CI_Controller {
public function index() {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$this->load->model('modes');
$this->load->model('logbook_model');
@@ -26,7 +26,7 @@ class Dxatlas extends CI_Controller {
public function export() {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$this->load->model('dxatlas_model');
@@ -48,7 +48,7 @@ class Dxatlas extends CI_Controller {
function generateFiles($wkdArray, $cfmArray, $band) {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$gridCfmArray = [];
$gridWkdArray = [];
@@ -105,7 +105,7 @@ class Dxatlas extends CI_Controller {
function makeZip($gridWkdString, $gridCfmString, $band) {
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$zipFileName = 'dxatlas_gridsquares_'. $band . '.zip';
// Prepare File
$file = tempnam(".", "zip");
diff --git a/application/controllers/Dxcalendar.php b/application/controllers/Dxcalendar.php
index 9a4029702..a9281c925 100644
--- a/application/controllers/Dxcalendar.php
+++ b/application/controllers/Dxcalendar.php
@@ -5,7 +5,7 @@ class Dxcalendar extends CI_Controller {
public function index() {
$this->load->model('user_model');
$this->load->model('logbook_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$data['page_title'] = __("DX Calendar");
diff --git a/application/controllers/Dxcluster.php b/application/controllers/Dxcluster.php
index 3a642256c..4414873f5 100644
--- a/application/controllers/Dxcluster.php
+++ b/application/controllers/Dxcluster.php
@@ -6,7 +6,7 @@ class Dxcluster extends CI_Controller {
{
parent::__construct();
$this->load->model('user_model');
- if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('notice', 'You\'re not allowed to do that!'); redirect('dashboard'); }
+ if(!$this->user_model->authorize(2)) { $this->session->set_flashdata('error', __("You're not allowed to do that!")); redirect('dashboard'); }
$this->load->model('dxcluster_model');
}
diff --git a/application/controllers/Eqsl.php b/application/controllers/Eqsl.php
index 6c70c9eee..98eae0ac3 100644
--- a/application/controllers/Eqsl.php
+++ b/application/controllers/Eqsl.php
@@ -20,7 +20,7 @@ class eqsl extends CI_Controller {
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
@@ -44,7 +44,7 @@ class eqsl extends CI_Controller {
public function import() {
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
@@ -141,7 +141,7 @@ class eqsl extends CI_Controller {
public function export() {
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
@@ -220,7 +220,7 @@ class eqsl extends CI_Controller {
function generateResultTable($custom_date_format, $rows) {
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
@@ -244,7 +244,7 @@ class eqsl extends CI_Controller {
function writeEqslNotSent($qslsnotsent, $custom_date_format) {
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
$table = '
diff --git a/application/controllers/Accumulated.php b/application/controllers/Accumulated.php
index 3f024d14b..97be191a8 100644
--- a/application/controllers/Accumulated.php
+++ b/application/controllers/Accumulated.php
@@ -4,50 +4,69 @@ defined('BASEPATH') or exit('No direct script access allowed');
class Accumulated extends CI_Controller
{
- function __construct()
- {
+ function __construct() {
parent::__construct();
$this->load->model('user_model');
if (!$this->user_model->authorize(2)) {
- $this->session->set_flashdata('notice', 'You\'re not allowed to do that!');
+ $this->session->set_flashdata('error', __("You're not allowed to do that!"));
redirect('dashboard');
}
}
- public function index()
- {
- // Render Page
- $data['page_title'] = __("Accumulated Statistics");
+ public function index() {
+ // Render Page
+ $data['page_title'] = __("Accumulated Statistics");
- $this->load->model('bands');
+ $this->load->model('bands');
- $data['worked_bands'] = $this->bands->get_worked_bands(); // Used in the view for band select
+ $data['worked_bands'] = $this->bands->get_worked_bands(); // Used in the view for band select
- $this->load->model('modes');
+ $this->load->model('modes');
- $data['modes'] = $this->modes->active();
+ if (($this->input->post('Propmode') != NULL) && ($this->input->post('Propmode') != '0')) { // Set, but not "All"
+ $data['propmode'] = $this->security->xss_clean($this->input->post('Propmode'));
+ } else {
+ if (($this->session->userdata('user_default_band') == 'SAT') && ($this->input->post('propmode') == NULL)){ // Not set, and empty and default is SAT?
+ $data['propmode']='SAT';
+ } else { // Not set and empty and no SAT as default?
+ $data['propmode'] = 'All';
+ }
+ }
- $this->load->view('interface_assets/header', $data);
- $this->load->view('accumulate/index');
- $this->load->view('interface_assets/footer');
+
+ $data['modes'] = $this->modes->active();
+
+ $this->load->view('interface_assets/header', $data);
+ $this->load->view('accumulate/index');
+ $this->load->view('interface_assets/footer');
}
/*
* Used for ajax-call in javascript to fetch the data and insert into table and chart
*/
- public function get_accumulated_data()
- {
- //load model
- $this->load->model('accumulate_model');
- $band = $this->input->post('Band');
- $award = $this->input->post('Award');
- $mode = $this->input->post('Mode');
- $period = $this->input->post('Period');
+ public function get_accumulated_data() {
- // get data
- $data = $this->accumulate_model->get_accumulated_data($band, $award, $mode, $period);
- header('Content-Type: application/json');
- echo json_encode($data);
+ if (($this->input->post('Propmode') != NULL) && ($this->input->post('Propmode') != '0')) { // Set, but not "All"
+ $propmode = $this->security->xss_clean($this->input->post('Propmode'));
+ } else {
+ if (($this->session->userdata('user_default_band') == 'SAT') && ($this->input->post('Propmode') == NULL)){ // Not set, and empty and default is SAT?
+ $propmode='SAT';
+ } else { // Not set and empty and no SAT as default?
+ $propmode = 'All';
+ }
+ }
+
+ //load model
+ $this->load->model('accumulate_model');
+ $band = xss_clean($this->input->post('Band'));
+ $award = xss_clean($this->input->post('Award'));
+ $mode = xss_clean($this->input->post('Mode'));
+ $period = xss_clean($this->input->post('Period'));
+
+ // get data
+ $data = $this->accumulate_model->get_accumulated_data($band, $award, $mode, $propmode, $period);
+ header('Content-Type: application/json');
+ echo json_encode($data);
}
}